==> cspace-ui-8.0.0-rc.3.tgz: package/src/plugins/extensions/associatedAuthority/form.jsx <==
export default (configContext) => {
  const {
    layoutComponents,
    lib,
    recordComponents,
  } = configContext;

  const {
    React,
  } = lib;

  const {
    Panel,
    Row,
  } = layoutComponents;

  const {
    Field,
  } = recordComponents;

  return (
    <>
      <Field name="personGroupList">
        <Field name="personGroup">
          <Panel>
            <Row>
              <Field name="person" />
              <Field name="personType" />
              <Field name="personStructuredDateGroup" />
              <Field name="personCitations">
                <Field name="personCitation" />
              </Field>
              <Field name="personNote" />
            </Row>
          </Panel>
        </Field>
      </Field>

      <Field name="peopleGroupList">
        <Field name="peopleGroup">
          <Panel>
            <Row>
              <Field name="people" />
              <Field name="peopleType" />
              <Field name="peopleStructuredDateGroup" />
              <Field name="peopleCitations">
                <Field name="peopleCitation" />
              </Field>
              <Field name="peopleNote" />
            </Row>
          </Panel>
        </Field>
      </Field>

      <Field name="organizationGroupList">
        <Field name="organizationGroup">
          <Panel>
            <Row>
              <Field name="organization" />
              <Field name="organizationType" />
              <Field name="organizationStructuredDateGroup" />
              <Field name="organizationCitations">
                <Field name="organizationCitation" />
              </Field>
              <Field name="organizationNote" />
            </Row>
          </Panel>
        </Field>
      </Field>

      <Field name="conceptGroupList">
        <Field name="conceptGroup">
          <Panel>
            <Row>
              <Field name="concept" />
              <Field name="conceptType" />
              <Field name="conceptStructuredDateGroup" />
              <Field name="conceptCitations">
                <Field name="conceptCitation" />
              </Field>
              <Field name="conceptNote" />
            </Row>
          </Panel>
        </Field>
      </Field>

      <Field name="placeGroupList">
        <Field name="placeGroup">
          <Panel>
            <Row>
              <Field name="place" />
              <Field name="placeType" />
              <Field name="placeStructuredDateGroup" />
              <Field name="placeCitations">
                <Field name="placeCitation" />
              </Field>
              <Field name="placeNote" />
            </Row>
          </Panel>
        </Field>
      </Field>

      <Field name="relatedPeriodGroupList">
        <Field name="relatedPeriodGroup">
          <Panel>
            <Row>
              <Field name="relatedPeriod" />
              <Field name="relatedPeriodType" />
              <Field name="relatedPeriodStructuredDateGroup" />
              <Field name="relatedPeriodCitations">
                <Field name="relatedPeriodCitation" />
              </Field>
              <Field name="relatedPeriodNote" />
            </Row>
          </Panel>
        </Field>
      </Field>
    </>
  );
};

==> cspace-ui-9.0.0-rc.1.tgz: package/src/plugins/extensions/associatedAuthority/form.jsx <==
export default (configContext) => {
  const {
    layoutComponents,
    lib,
    recordComponents,
  } = configContext;

  const {
    React,
  } = lib;

  const {
    Panel,
    Row,
  } = layoutComponents;

  const {
    Field,
  } = recordComponents;

  return (
    <>
      <Field name="assocPersonAuthGroupList">
        <Field name="assocPersonAuthGroup">
          <Panel>
            <Row>
              <Field name="person" />
              <Field name="personType" />
              <Field name="personStructuredDateGroup" />
              <Field name="personCitations">
                <Field name="personCitation" />
              </Field>
            </Row>
            <Field name="personNote" />
          </Panel>
        </Field>
      </Field>

      <Field name="assocPeopleAuthGroupList">
        <Field name="assocPeopleAuthGroup">
          <Panel>
            <Row>
              <Field name="people" />
              <Field name="peopleType" />
              <Field name="peopleStructuredDateGroup" />
              <Field name="peopleCitations">
                <Field name="peopleCitation" />
              </Field>
            </Row>
            <Field name="peopleNote" />
          </Panel>
        </Field>
      </Field>

      <Field name="assocOrganizationAuthGroupList">
        <Field name="assocOrganizationAuthGroup">
          <Panel>
            <Row>
              <Field name="organization" />
              <Field name="organizationType" />
              <Field name="organizationStructuredDateGroup" />
              <Field name="organizationCitations">
                <Field name="organizationCitation" />
              </Field>
            </Row>
            <Field name="organizationNote" />
          </Panel>
        </Field>
      </Field>

      <Field name="assocConceptAuthGroupList">
        <Field name="assocConceptAuthGroup">
          <Panel>
            <Row>
              <Field name="concept" />
              <Field name="conceptType" />
              <Field name="conceptStructuredDateGroup" />
              <Field name="conceptCitations">
                <Field name="conceptCitation" />
              </Field>
            </Row>
            <Field name="conceptNote" />
          </Panel>
        </Field>
      </Field>

      <Field name="assocPlaceAuthGroupList">
        <Field name="assocPlaceAuthGroup">
          <Panel>
            <Row>
              <Field name="place" />
              <Field name="placeType" />
              <Field name="placeStructuredDateGroup" />
              <Field name="placeCitations">
                <Field name="placeCitation" />
              </Field>
            </Row>
            <Field name="placeNote" />
          </Panel>
        </Field>
      </Field>

      <Field name="assocChronologyAuthGroupList">
        <Field name="assocChronologyAuthGroup">
          <Panel>
            <Row>
              <Field name="chronology" />
              <Field name="chronologyType" />
              <Field name="chronologyStructuredDateGroup" />
              <Field name="chronologyCitations">
                <Field name="chronologyCitation" />
              </Field>
            </Row>
            <Field name="chronologyNote" />
          </Panel>
        </Field>
      </Field>
    </>
  );
};
